Crate some_local_executor

Crate some_local_executor 

It’s a simple single-threaded executor.

This is a reference executor for the some_executor crate.

By leveraging the features in some_executor, this project provides a rich API:

  1. Tasks and cancellation
  2. Observers and notifications
  3. Priorities and scheduling
  4. task-locals

…in about a page of code.

By writing code against this executor, you’re basically compatible with every other executor supported by some_executor.

Re-exports

pub use some_executor;

Modules

some_executor_adapter
Provides an implementation of some_executor::SomeExecutorExt, so that the executor can be used from multiple threads.

Structs

Executor
The main executor type.

Type Aliases

Configuration
Task